# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetRiskCountResponseBody(DaraModel):
    def __init__(
        self,
        aliyun_asset_certificate_expired_count: int = None,
        aliyun_asset_certificate_will_expired_count: int = None,
        buy_certificate_expire_count: int = None,
        buy_certificate_not_deployment_count: int = None,
        buy_certificate_not_trustee_count: int = None,
        buy_certificate_will_expired_count: int = None,
        buy_checked_fail_count: int = None,
        domain_asset_not_monitor_count: int = None,
        free_certificate_expire_count: int = None,
        free_certificate_not_deployment_count: int = None,
        free_certificate_will_expired_count: int = None,
        free_checked_fail_count: int = None,
        multi_cloud_asset_certificate_expired_count: int = None,
        multi_cloud_asset_certificate_will_expired_count: int = None,
        request_id: str = None,
        upload_certificate_expire_count: int = None,
        upload_certificate_not_deployment_count: int = None,
        upload_certificate_not_notice_count: int = None,
        upload_certificate_will_expired_count: int = None,
    ):
        self.aliyun_asset_certificate_expired_count = aliyun_asset_certificate_expired_count
        self.aliyun_asset_certificate_will_expired_count = aliyun_asset_certificate_will_expired_count
        self.buy_certificate_expire_count = buy_certificate_expire_count
        self.buy_certificate_not_deployment_count = buy_certificate_not_deployment_count
        self.buy_certificate_not_trustee_count = buy_certificate_not_trustee_count
        self.buy_certificate_will_expired_count = buy_certificate_will_expired_count
        self.buy_checked_fail_count = buy_checked_fail_count
        self.domain_asset_not_monitor_count = domain_asset_not_monitor_count
        self.free_certificate_expire_count = free_certificate_expire_count
        self.free_certificate_not_deployment_count = free_certificate_not_deployment_count
        self.free_certificate_will_expired_count = free_certificate_will_expired_count
        self.free_checked_fail_count = free_checked_fail_count
        self.multi_cloud_asset_certificate_expired_count = multi_cloud_asset_certificate_expired_count
        self.multi_cloud_asset_certificate_will_expired_count = multi_cloud_asset_certificate_will_expired_count
        self.request_id = request_id
        self.upload_certificate_expire_count = upload_certificate_expire_count
        self.upload_certificate_not_deployment_count = upload_certificate_not_deployment_count
        self.upload_certificate_not_notice_count = upload_certificate_not_notice_count
        self.upload_certificate_will_expired_count = upload_certificate_will_expired_count

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.aliyun_asset_certificate_expired_count is not None:
            result['AliyunAssetCertificateExpiredCount'] = self.aliyun_asset_certificate_expired_count

        if self.aliyun_asset_certificate_will_expired_count is not None:
            result['AliyunAssetCertificateWillExpiredCount'] = self.aliyun_asset_certificate_will_expired_count

        if self.buy_certificate_expire_count is not None:
            result['BuyCertificateExpireCount'] = self.buy_certificate_expire_count

        if self.buy_certificate_not_deployment_count is not None:
            result['BuyCertificateNotDeploymentCount'] = self.buy_certificate_not_deployment_count

        if self.buy_certificate_not_trustee_count is not None:
            result['BuyCertificateNotTrusteeCount'] = self.buy_certificate_not_trustee_count

        if self.buy_certificate_will_expired_count is not None:
            result['BuyCertificateWillExpiredCount'] = self.buy_certificate_will_expired_count

        if self.buy_checked_fail_count is not None:
            result['BuyCheckedFailCount'] = self.buy_checked_fail_count

        if self.domain_asset_not_monitor_count is not None:
            result['DomainAssetNotMonitorCount'] = self.domain_asset_not_monitor_count

        if self.free_certificate_expire_count is not None:
            result['FreeCertificateExpireCount'] = self.free_certificate_expire_count

        if self.free_certificate_not_deployment_count is not None:
            result['FreeCertificateNotDeploymentCount'] = self.free_certificate_not_deployment_count

        if self.free_certificate_will_expired_count is not None:
            result['FreeCertificateWillExpiredCount'] = self.free_certificate_will_expired_count

        if self.free_checked_fail_count is not None:
            result['FreeCheckedFailCount'] = self.free_checked_fail_count

        if self.multi_cloud_asset_certificate_expired_count is not None:
            result['MultiCloudAssetCertificateExpiredCount'] = self.multi_cloud_asset_certificate_expired_count

        if self.multi_cloud_asset_certificate_will_expired_count is not None:
            result['MultiCloudAssetCertificateWillExpiredCount'] = self.multi_cloud_asset_certificate_will_expired_count

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.upload_certificate_expire_count is not None:
            result['UploadCertificateExpireCount'] = self.upload_certificate_expire_count

        if self.upload_certificate_not_deployment_count is not None:
            result['UploadCertificateNotDeploymentCount'] = self.upload_certificate_not_deployment_count

        if self.upload_certificate_not_notice_count is not None:
            result['UploadCertificateNotNoticeCount'] = self.upload_certificate_not_notice_count

        if self.upload_certificate_will_expired_count is not None:
            result['UploadCertificateWillExpiredCount'] = self.upload_certificate_will_expired_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AliyunAssetCertificateExpiredCount') is not None:
            self.aliyun_asset_certificate_expired_count = m.get('AliyunAssetCertificateExpiredCount')

        if m.get('AliyunAssetCertificateWillExpiredCount') is not None:
            self.aliyun_asset_certificate_will_expired_count = m.get('AliyunAssetCertificateWillExpiredCount')

        if m.get('BuyCertificateExpireCount') is not None:
            self.buy_certificate_expire_count = m.get('BuyCertificateExpireCount')

        if m.get('BuyCertificateNotDeploymentCount') is not None:
            self.buy_certificate_not_deployment_count = m.get('BuyCertificateNotDeploymentCount')

        if m.get('BuyCertificateNotTrusteeCount') is not None:
            self.buy_certificate_not_trustee_count = m.get('BuyCertificateNotTrusteeCount')

        if m.get('BuyCertificateWillExpiredCount') is not None:
            self.buy_certificate_will_expired_count = m.get('BuyCertificateWillExpiredCount')

        if m.get('BuyCheckedFailCount') is not None:
            self.buy_checked_fail_count = m.get('BuyCheckedFailCount')

        if m.get('DomainAssetNotMonitorCount') is not None:
            self.domain_asset_not_monitor_count = m.get('DomainAssetNotMonitorCount')

        if m.get('FreeCertificateExpireCount') is not None:
            self.free_certificate_expire_count = m.get('FreeCertificateExpireCount')

        if m.get('FreeCertificateNotDeploymentCount') is not None:
            self.free_certificate_not_deployment_count = m.get('FreeCertificateNotDeploymentCount')

        if m.get('FreeCertificateWillExpiredCount') is not None:
            self.free_certificate_will_expired_count = m.get('FreeCertificateWillExpiredCount')

        if m.get('FreeCheckedFailCount') is not None:
            self.free_checked_fail_count = m.get('FreeCheckedFailCount')

        if m.get('MultiCloudAssetCertificateExpiredCount') is not None:
            self.multi_cloud_asset_certificate_expired_count = m.get('MultiCloudAssetCertificateExpiredCount')

        if m.get('MultiCloudAssetCertificateWillExpiredCount') is not None:
            self.multi_cloud_asset_certificate_will_expired_count = m.get('MultiCloudAssetCertificateWillExpiredCount')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('UploadCertificateExpireCount') is not None:
            self.upload_certificate_expire_count = m.get('UploadCertificateExpireCount')

        if m.get('UploadCertificateNotDeploymentCount') is not None:
            self.upload_certificate_not_deployment_count = m.get('UploadCertificateNotDeploymentCount')

        if m.get('UploadCertificateNotNoticeCount') is not None:
            self.upload_certificate_not_notice_count = m.get('UploadCertificateNotNoticeCount')

        if m.get('UploadCertificateWillExpiredCount') is not None:
            self.upload_certificate_will_expired_count = m.get('UploadCertificateWillExpiredCount')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_cas20200407 import models as main_models
from darabonba.model import DaraModel

class ListDeploymentJobResponseBody(DaraModel):
    def __init__(
        self,
        current_page: int = None,
        data: List[main_models.ListDeploymentJobResponseBodyData] = None,
        request_id: str = None,
        show_size: int = None,
        total: int = None,
    ):
        # The page number. Default value: 1.
        self.current_page = current_page
        # The data returned for the request.
        self.data = data
        # The request ID.
        self.request_id = request_id
        # The number of deployment tasks per page. Default value: **50**.
        self.show_size = show_size
        # The total number of deployment tasks returned.
        self.total = total

    def validate(self):
        if self.data:
            for v1 in self.data:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        result['Data'] = []
        if self.data is not None:
            for k1 in self.data:
                result['Data'].append(k1.to_map() if k1 else None)

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.show_size is not None:
            result['ShowSize'] = self.show_size

        if self.total is not None:
            result['Total'] = self.total

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        self.data = []
        if m.get('Data') is not None:
            for k1 in m.get('Data'):
                temp_model = main_models.ListDeploymentJobResponseBodyData()
                self.data.append(temp_model.from_map(k1))

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('ShowSize') is not None:
            self.show_size = m.get('ShowSize')

        if m.get('Total') is not None:
            self.total = m.get('Total')

        return self

class ListDeploymentJobResponseBodyData(DaraModel):
    def __init__(
        self,
        cert_domain: str = None,
        cert_type: str = None,
        del_: int = None,
        end_time: str = None,
        gmt_create: str = None,
        gmt_modified: str = None,
        id: int = None,
        instance_id: str = None,
        job_type: str = None,
        name: str = None,
        product_name: str = None,
        rollback: int = None,
        schedule_time: str = None,
        start_time: str = None,
        status: str = None,
        user_id: int = None,
    ):
        # The domain names bound to the certificate of the deployment task.
        self.cert_domain = cert_domain
        # The type of the certificate. Valid values:
        # 
        # *   **upload**: uploaded certificate
        # *   **buy**: purchased certificate
        # *   **free**: free certificate, available only on the China site (aliyun.com)
        self.cert_type = cert_type
        # Indicates whether the deployment task is deleted. Valid values:
        # 
        # *   **0**: not deleted
        # *   **1**: deleted
        self.del_ = del_
        # The end time of the deployment task.
        self.end_time = end_time
        # The time when the deployment task was created.
        self.gmt_create = gmt_create
        # The time when the deployment task was last modified.
        self.gmt_modified = gmt_modified
        # The ID of the deployment task. You can use the ID to query the details and status of the deployment task.
        self.id = id
        # The instance ID of the deployment task.
        self.instance_id = instance_id
        # The type of the deployment task.
        # 
        # *   **cloud**: multi-cloud deployment task.
        # *   **user**: cloud service deployment task. This type of task does not support ECS instances.
        self.job_type = job_type
        # The name of the deployment task.
        self.name = name
        # The cloud service included in the resources of the deployment task.
        self.product_name = product_name
        # Indicates whether the rollback worker is included. For example, if a cloud service involved in a deployment task has been rolled back, **1** is returned. Valid values:
        # 
        # *   **0**: The rollback worker is not included.
        # *   **1**: The rollback worker is included.
        self.rollback = rollback
        # The time when the deployment task was scheduled.
        self.schedule_time = schedule_time
        # The start time of the deployment task.
        self.start_time = start_time
        # The status of the deployment task. Valid values:
        # 
        # *   **pending**
        # *   **editing**
        # *   **scheduling**
        # *   **processing**
        # *   **error**
        # *   **success**
        self.status = status
        # The ID of the user.
        self.user_id = user_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cert_domain is not None:
            result['CertDomain'] = self.cert_domain

        if self.cert_type is not None:
            result['CertType'] = self.cert_type

        if self.del_ is not None:
            result['Del'] = self.del_

        if self.end_time is not None:
            result['EndTime'] = self.end_time

        if self.gmt_create is not None:
            result['GmtCreate'] = self.gmt_create

        if self.gmt_modified is not None:
            result['GmtModified'] = self.gmt_modified

        if self.id is not None:
            result['Id'] = self.id

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.job_type is not None:
            result['JobType'] = self.job_type

        if self.name is not None:
            result['Name'] = self.name

        if self.product_name is not None:
            result['ProductName'] = self.product_name

        if self.rollback is not None:
            result['Rollback'] = self.rollback

        if self.schedule_time is not None:
            result['ScheduleTime'] = self.schedule_time

        if self.start_time is not None:
            result['StartTime'] = self.start_time

        if self.status is not None:
            result['Status'] = self.status

        if self.user_id is not None:
            result['UserId'] = self.user_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CertDomain') is not None:
            self.cert_domain = m.get('CertDomain')

        if m.get('CertType') is not None:
            self.cert_type = m.get('CertType')

        if m.get('Del') is not None:
            self.del_ = m.get('Del')

        if m.get('EndTime') is not None:
            self.end_time = m.get('EndTime')

        if m.get('GmtCreate') is not None:
            self.gmt_create = m.get('GmtCreate')

        if m.get('GmtModified') is not None:
            self.gmt_modified = m.get('GmtModified')

        if m.get('Id') is not None:
            self.id = m.get('Id')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('JobType') is not None:
            self.job_type = m.get('JobType')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('ProductName') is not None:
            self.product_name = m.get('ProductName')

        if m.get('Rollback') is not None:
            self.rollback = m.get('Rollback')

        if m.get('ScheduleTime') is not None:
            self.schedule_time = m.get('ScheduleTime')

        if m.get('StartTime') is not None:
            self.start_time = m.get('StartTime')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('UserId') is not None:
            self.user_id = m.get('UserId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class UploadCsrRequest(DaraModel):
    def __init__(
        self,
        csr: str = None,
        key: str = None,
        name: str = None,
    ):
        # The content of the CSR.
        # 
        # This parameter is required.
        self.csr = csr
        # The private key content of the certificate in the PEM format.
        self.key = key
        # The name of the CSR.
        self.name = name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.csr is not None:
            result['Csr'] = self.csr

        if self.key is not None:
            result['Key'] = self.key

        if self.name is not None:
            result['Name'] = self.name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Csr') is not None:
            self.csr = m.get('Csr')

        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListCloudAccessRequest(DaraModel):
    def __init__(
        self,
        cloud_name: str = None,
        current_page: int = None,
        secret_id: str = None,
        show_size: int = None,
    ):
        # The cloud service provider. Set the value to **Tencent**, which indicates Tencent Cloud.
        self.cloud_name = cloud_name
        # The page number. Default value: 1.
        self.current_page = current_page
        # The AccessKey ID that is used to access cloud resources.
        self.secret_id = secret_id
        # The number of entries per page. Valid values: **10**, **20**, and **50**.
        self.show_size = show_size

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cloud_name is not None:
            result['CloudName'] = self.cloud_name

        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        if self.secret_id is not None:
            result['SecretId'] = self.secret_id

        if self.show_size is not None:
            result['ShowSize'] = self.show_size

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CloudName') is not None:
            self.cloud_name = m.get('CloudName')

        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        if m.get('SecretId') is not None:
            self.secret_id = m.get('SecretId')

        if m.get('ShowSize') is not None:
            self.show_size = m.get('ShowSize')

        return self

